<?php

namespace Drupal\qtools_profiler\Cache;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\qtools_profiler\Access\ProfilerPreviewAccessCheck;

/**
 * Defines cache context if cache profiler preview is accessible or not.
 */
class ProfilerPreviewAccessContext implements CacheContextInterface {

  // Cache contexts.
  const CACHE_CONTEXT_KEY = 'qtools_profiler_preview_access';

  /**
   * Constructs a new CustomerCanOrderContext service.
   */
  public function __construct(
    protected AccountProxyInterface $currentUser,
    protected ProfilerPreviewAccessCheck $profilerPreviewAccessCheck,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function getLabel() {
    return t("Profiler preview accessible.");
  }

  /**
   * {@inheritdoc}
   */
  public function getContext() {
    $access = $this->profilerPreviewAccessCheck->access($this->currentUser);
    return $access->isAllowed() ? '1' : '0';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata() {
    return new CacheableMetadata();
  }

}
